extras-buildsys/server ArchJob.py,1.25,1.26

Daniel Williams (dcbw) fedora-extras-commits at redhat.com
Thu Feb 23 19:14:06 UTC 2006


Author: dcbw

Update of /cvs/fedora/extras-buildsys/server
In directory cvs-int.fedora.redhat.com:/tmp/cvs-serv2084/server

Modified Files:
	ArchJob.py 
Log Message:
Increase # of download tries to 10, and import OpenSSL to fix traceback in die()


Index: ArchJob.py
===================================================================
RCS file: /cvs/fedora/extras-buildsys/server/ArchJob.py,v
retrieving revision 1.25
retrieving revision 1.26
diff -u -r1.25 -r1.26
--- ArchJob.py	16 Feb 2006 18:33:34 -0000	1.25
+++ ArchJob.py	23 Feb 2006 19:13:48 -0000	1.26
@@ -22,6 +22,7 @@
 import os
 import threading
 import urllib
+import OpenSSL
 from plague import FileDownloader
 from plague import CommonErrors
 
@@ -221,8 +222,8 @@
         if status == 'done':
             dl_dict[DL_STATUS] = STATUS_DONE
         elif status == 'failed':
-            # Retry the download up to 5 times, then fail it
-            if dl_dict[DL_RETRIES] >= 5:
+            # Retry the download up to 10 times, then fail it
+            if dl_dict[DL_RETRIES] >= 10:
                 dl_dict[DL_STATUS] = STATUS_ERROR
             else:
                 print "%s (%s/%s): Failed to retrieve %s (attempt %d), trying again..." % (self.par_job.uid,




More information about the scm-commits mailing list